# -----------------------------------------------------------------------------
sub infArc
{
  ($thishost) = @_;

  if ($up[$thishost] ne "Y")
  {
    &logit("(Down/Inhibited)",$thishost);
    return 1;
  }
    
  if ($db_status[$thishost] eq "R")
  {
    &logit("HDR Secondary Instance - backup age checking not applicable",$thishost);
    return 1;
  }
    
  if ($chunks_ok[$thishost] ne "Y")
  {
    logit("(Chunk(s) down)",$thishost);
    return 1;
  }

  if ($backup_age[$thishost] eq "")
  {
    logit("Backup Aging not requested for this instance",$thishost);
    return 0;
  }

  #
  # bb 11Oct99 - Check to see if there is a backup age inhibit 
  # entry.
  #
  if ($use_repository eq "Y")
  {
    $rc = &baICheck($thishost);
    if ($rc > 0)
    {
      $bainhibit[$thishost] = 1;
      $bckhours_c[$thishost] = "black";
      $bckhours[$thishost]   = "(I)";
      $msg = sprintf("Backup Age Checking Inhibited - Start: %s End: %s Created: %s User: %s Reason: %s",$bai_sts,$bai_ets,$bai_ts,$bai_user,$bai_reason);
      &logit($msg,$thishost);
      return 0 ;
    }
  }
  else
  {
    $msg = sprintf("Backup Aging Inhibit not possible because Use_Oracle != Y");
    &logit($msg,$thishost);
  }

  $running  = "?";
  $arc_type = "?";
  $l0_date  = "?";
  $l1_date  = "?";
  $this_age = "?";

  #
  # infLocks fills in backup_method[] with A or T. 
  #

  if ($backup_method[$thishost] eq "A")
  {
    $arc_type = "onarch" 
  }

  if ($backup_method[$thishost] eq "T" || $backup_method[$thishost] eq "B")
  {
    $arc_type = "ontape" 
  }
   
  if ($arc_type ne "ontape" && $arc_type ne "onarch")
  {
    $msg = "Cannot determine Informix backup type: $arc_type";
    &error_msg($msg,$thishost);
    &downloadFlagOff($thishost);
    return 1;
  }

  #
  # ontape backups
  #

  if ($arc_type eq "ontape")
  {
    logit("Archive Type: ontape (no rows in sysmaster:arc_request)",$thishost);

    if (system("$pgmdir/dbamon_arc_ontape $hostname[$thishost] $rootpath[$thishost] $rootoffs[$thishost] $userid[$thishost] $comm_method[$thishost] > $tmpfl4 2>&1") != 0)
    {
      &logit("dbamon_arc_ontape error",$thishost);
      &error_msg("dbamon_arc_ontape error",$thishost,$tmpfl4);
      return 1;
    }
    ##system("cat $tmpfl4");

    $found_flag = 0;

    open(TMPFL4, "$tmpfl4"  ) || &error_msg("Can't open input $tmpfl4 - $!");
    while(<TMPFL4>)
    {
      &parse;

      if ($F1 eq "Backup_running:") 
      {
        $running = $F2;
      }

      if ($F1 eq "L0_date:") 
      {
        $l0_date = $F2
      }

      if ($F1 eq "L1_date:") 
      {
        $l1_date = $F2
      }

      if ($F1 eq "L0_delta:") 
      {
        $mrl0days[$thishost] = int($F2 / 24);
      }

      if ($F1 eq "Min_delta:") 
      {
        $this_age = $F2;
        $bckhours[$thishost] = $this_age;
        $bckhours_c[$thishost] = "lime";
   
	&logDetails($thishost,"<h3>Backup Data - ontape</h3>");
	&logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
	&logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
	&logDetails($thishost,"<tr><td>$f_s <b>Hours Since Last Backup:<td align=right>$f_s $this_age");
	&logDetails($thishost,"<tr><td>$f_s <b>Most Recent L0 Backup:<td align=right>$f_s $l0_date");
	&logDetails($thishost,"<tr><td>$f_s <b>Most Recent L1 Backup:<td align=right>$f_s $l1_date");
	&logDetails($thishost,"<tr><td>$f_s <b>Most Recent L2 Backup:<td align=right>$f_s $l2_date");
	&logDetails($thishost,"<tr><td>$f_s <b>Backup rerun command (from DBC File):<td align=right>$f_s $backup_command[$thishost]");
	&logDetails($thishost,"</table><hr>");

	if ($this_age == -1)
	{
          &event("C",$thishost,"No onbar/ontape archive data retrieved (No backup ever or DBAmon pgm. error)","BkpNoDat","DBA209C",$tmpfl4);
	  return;
	}
	if ($this_age < 0)
	{
          open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
	  print TMPFL6 "Archive Details:\n";
	  print TMPFL6 "Hours since last backup: $this_age \n";
	  print TMPFL6 "Most recent L0 backup:   $l0_date  \n";
	  print TMPFL6 "Most recent L1 backup:   $l1_date  \n";
	  print TMPFL6 "\nRaw Data:\n";
          close(TMPFL6);
	  system("cat $tmpfl4 >> $tmpfl6");

          &event("C",$thishost,"Hours since last backup ($this_age) is a negative value","BkpNeg","DBA216C",$tmpfl6);
          last;
	}

        $found_flag = 1;

        #
        # Check age vs. threashold - backup NOT running and backup_rerun command specified
        #

        if ($this_age > $backup_age[$thishost] && $running ne "Y" && $backup_command[$thishost] ne "" && $backup_rerun_iter[$thishost] != ($iter_count - 1))
        {
          # Issue rerun
	  $cmd = "$probe[$thishost] bkrun \"$backup_command[$thishost]\"";
          remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$cmd",$tmpfl3,$thishost);

	  ##system("cat " tmpfl3)
	  $backup_rerun_iter[$thishost] = $iter_count;

          $bckhours_c[$thishost] = "yellow";

          $rounded1 = int($this_age / 10);
          $rounded1 = $rounded1 * 10;
          $rounded2 = $rounded1 + 9;

          open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
	  print TMPFL6 "Archive Details:\n";
	  print TMPFL6 "Hours since last backup: $this_age \n";
	  print TMPFL6 "Most recent L0 backup:   $l0_date  \n";
	  print TMPFL6 "Most recent L1 backup:   $l1_date  \n";
          print TMPFL6 "Backup Rerun Command for this instance: $backup_command[$thishost] \n";
	  print TMPFL6 "\nRaw Data:\n";
          close(TMPFL6);
	  system("cat $tmpfl4 >> $tmpfl6");

          &event("W",$thishost,"(Backup Was Rerun) $rounded1-$rounded2 Hours since last good onbar/ontape backup (threshold=$backup_age[$thishost])","BkpAgeReran","DBA390W",$tmpfl6);
          last;
        }

        #
        # Check age vs. threashold - backup NOT running
        #

        if ($this_age > $backup_age[$thishost] && $running ne "Y")
        {
          $bckhours_c[$thishost] = "hotpink";

          $rounded1 = int($this_age / 10);
          $rounded1 = $rounded1 * 10;
          $rounded2 = $rounded1 + 9;
          
          open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
	  print TMPFL6 "Archive Details:\n";
	  print TMPFL6 "Hours since last backup: $this_age \n";
	  print TMPFL6 "Most recent L0 backup:   $l0_date  \n";
	  print TMPFL6 "Most recent L1 backup:   $l1_date  \n";
          print TMPFL6 "Backup Rerun Command for this instance: $backup_command[$thishost] \n";
	  print TMPFL6 "\nRaw Data:\n";
          close(TMPFL6);
	  system("cat $tmpfl4 >> $tmpfl6");

          &event("C",$thishost,"$rounded1-$rounded2 Hours since last good onbar/ontape backup (threshold=$backup_age[$thishost])","BkpAge","DBA211C",$tmpfl6);
          last;
        }

        if ($this_age > $backup_age[$thishost] && $running eq "Y")
        {
          $bckhours_c[$thishost] = "yellow";

          $rounded1 = int($this_age / 10);
          $rounded1 = $rounded1 * 10;
          $rounded2 = $rounded1 + 9;

          open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
	  print TMPFL6 "Archive Details:\n";
	  print TMPFL6 "Hours since last backup: $this_age \n";
	  print TMPFL6 "Most recent L0 backup:   $l0_date  \n";
	  print TMPFL6 "Most recent L1 backup:   $l1_date  \n";
          print TMPFL6 "Backup Rerun Command for this instance: $backup_command[$thishost] \n";
	  print TMPFL6 "\nRaw Data:\n";
          close(TMPFL6);
	  system("cat $tmpfl4 >> $tmpfl6");

          &event("W",$thishost,"(Backup Running Now) $rounded1-$rounded2 Hours since last good onbar/ontape backup (threshold=$backup_age[$thishost])","BkpAge","DBA390W",$tmpfl6);
          last;
        }

        if ($this_age <= $backup_age[$thishost])
        {
          &logit("OK (onbar/ontape age=$this_age recent L0 age=$mrl0days[$thishost] days)",$thishost);
          last;
        }

      } 
    }  # end of while 
    close(TMPFL4);
  }

  #
  # onarchive backups
  #

  else  # backup_type: onarch
  {
    $msg = sprintf("Archive Type: onarchive (rows found in sysmaster:arc_request)",$arc_type);
    logit($msg,$thishost);

    $reran_flag = 0;

    remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$probe[$thishost] onarc",$tmpfl4,$thishost);
    ##system("cat $tmpfl4");

    $this_age = -1;

    &logDetails($thishost,"<h3>Informix Backup History - Backup Method: ONArchive - All Backups During the Last 45 Days</h3>");
    &logDetails($thishost,"<h4>All ONArchive Backups During the Last 45 Days</h4>");
    &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
    &logDetails($thishost,"<tr bgcolor=slate><th>Data<th>Time<th>Level<th>RID<th>DBSpace Set<th>Days Ago</tr>");
   
    open(TMPFL4, "$tmpfl4"  ) || &error_msg("Can't open input $tmpfl4 - $!");
    while(<TMPFL4>)
    {
      &parse;
      if ($F1 eq "HOURS:") 
      {
        $this_age = $F2;
        $bckhours[$thishost] = $this_age;
        $bckhours_c[$thishost] = "lime";
      }
      if ($F1 eq "RUNNING:") 
      {
        $running = $F2;
      }
      if ($F1 eq "MRL0DAYSAGO:") 
      {
        $mrl0days[$thishost] = int($F2);
      }
      if ($F1 eq "RPT:" && substr($F2,0,1) eq "2") 
      {
        &logDetails($thishost,"<tr><td>$F2<th>$F3<th>$F4<th>$F5<th>$F6<th>$F7</tr>");
      }
    }
    &logDetails($thishost,"</table>");

    &logDetails($thishost,"<h4>Backup Parameters</h4>");
    &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
    &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
    &logDetails($thishost,"<tr><td>$f_s Age of Most Recent Backup (Hours):<td>$f_s $this_age");
    &logDetails($thishost,"<tr><td>$f_s Age of Most Recent LVL0 Backup (Days):<td>$f_s $mrl0days[$thishost]");
    &logDetails($thishost,"<tr><td>$f_s Backup Running Now?:<td>$f_s $running");
    &logDetails($thishost,"</table><hr>");

    #
    # Check age vs. threashold - backup NOT running and backup_rerun command specified
    #
    if ($this_age > $backup_age[$thishost] && $running ne "Y" && $backup_command[$thishost] ne "" && $backup_rerun_iter[$thishost] != ($iter_count - 1))
    {
      # Issue rerun
      $cmd = "$probe[$thishost] bkrun \"$backup_command[$thishost]\"";
      ##print "backup rerun cmd="cmd " $thishost=" $thishost

      remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$cmd",$tmpfl3,$thishost);
      ##system("cat $tmpfl3");
      $backup_rerun_iter[$thishost] = $iter_count;
      $reran_flag = 1;

      $bckhours_c[$thishost] = "yellow";
      $rounded1 = int($this_age / 10);
      $rounded1 = $rounded1 * 10;
      $rounded2 = $rounded1 + 9;

      &event("W",$thishost,"(Backup Was Rerun) $rounded1-$rounded2 Hours since last good onarchive backup (threshold=$backup_age[$thishost])","BkpAgeReran","DBA391W",$tmpfl4);
    }

    #
    # Check age vs. threshold - backup NOT running 
    #
    if ($this_age > $backup_age[$thishost] && $running ne "Y" && $reran_flag != 1)
    {
      $bckhours_c[$thishost] = "hotpink";

      $rounded1 = int($this_age / 10);
      $rounded1 = $rounded1 * 10;
      $rounded2 = $rounded1 + 9;
        
      &event("C",$thishost,"(Backup Not Running) $rounded1-$rounded2 Hours since last good onarchive backup (threshold=$backup_age[$thishost])","BkpAge","DBA210CW",$tmpfl4);
    }

    #
    # Check age vs. threashold - backup IS running 
    #
    if ($this_age > $backup_age[$thishost] && $running eq "Y")
    {
      $bckhours_c[$thishost] = "yellow";
      $rounded1 = int($this_age / 10);
      $rounded1 = $rounded1 * 10;
      $rounded2 = $rounded1 + 9;

      &event("W",$thishost,"(Backup Running Now) $rounded1-$rounded2 Hours since last good onarchive backup (threshold=$backup_age[$thishost])","BkpAge","DBA391W",$tmpfl4);
    }

    if ($this_age <= $backup_age[$thishost])
    {
      $msg = sprintf("OK (onarchive age=%s most recent L0 age=%s days)",$this_age,$rl0days[$thishost]);
      &logit($msg,$thishost);
    }
  }

  $mr_backup_date[$thishost] = &timeToText(time - ($this_age * 3600));
  ##print "this_age=$this_age mr_backup_date=$mr_backup_date[$thishost]\n";

  if ($mrl0days[$thishost] > $l0_age[$thishost])
  {
    &event("C",$thishost," $mrl0days[$thishost] Days since last good Level=0 backup (threshold=$l0_age[$thishost])","L0Age","DBA400C",$tmpfl4);
  }
}
# -----------------------------------------------------------------------------
1;
